C
C------------------------------------------------------
C
C     Problem:    OBSTACLE
C
C     Date:       05.02.00
C
C------------------------------------------------------
C
*     REAL CONSTANT
      g = 1
C
C------------------------------------------------------
C
*     SET OF INDICES
      ind = 1..20
C
C------------------------------------------------------
C
C   - Independent variables in the following order:
C     1. parameters to be estimated (p)
C     2. variables identifying solution of partial
C        differential equations, first the differential ones,
C        then the algebraic variables (u)
C     3. variables identifying first spatial derivatives of
C        solution of partial differential equations (u_x)
C     4. variables identifying second spatial derivatives of
C        solution of partial differential equations (u_xx)
C     5. variables identifying solution of coupled
C        ordinary differential equations (v)
C     6. variables for flux functions, if available (one
C        variable for each function (f), then one for
C        each derivative (f_x). These names can be
C        inserted subsequently. Note that flux variables
C        must be declared for each PDE.
C     7. spatial variable (x)
C     8. time variable (t)
C
*     VARIABLE
      b, u0
      h, v, h_x, v_x, h_xx, v_xx, fh, fv, fh_x, fv_x, x, t
C
C------------------------------------------------------
C
C   - Functions defining the flux depending on u and u_x,
C     if available (order: functions in first area, func-
C     tions in second area, etc.):
C
*     FUNCTION fluxh
      fluxh = -v
C
*     FUNCTION fluxv
      if (h.gt.0) then
        fluxv = -v**2/h - 0.5*g*h**2   
      else
        fluxv = 0
      endif
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     partial differential equations (order: differential
C     followed by algebraic functions in first area, then
C     differential followed by algebraic functions in 
C     second area, etc.):
C
*     FUNCTION h_t
      h_t = fh_x
C
*     FUNCTION u_t
      if ((x.gt.-2).and.(x.lt.2)) then
        z0x = -0.5*b*x
      else
        z0x = 0
      endif
      v_t = fv_x - g*h*z0x
C
C------------------------------------------------------
C
C   - Initial values of system of partial differential
C     equations for t=0 (order: initial values for 
C     differential followed by algebraic variables in 
C     first area, then differential followed by algebraic
C     *variables in second area, etc.):
C
*     FUNCTION h_0
      if ((x.gt.-2).and.(x.lt.2)) then
        h0 = 1- b*(1 - 0.25*x**2)
      else
        h0 = 1
      endif
      h_0 = h0
C
*     FUNCTION v_0
      if ((x.gt.-2).and.(x.lt.2)) then
        v0 = b*(1 - 0.25*x**2)
      else
        v0 = 0
      endif
      v_0 = v0
C
C------------------------------------------------------
C
C   - Functions defining right-hand side of system of 
C     coupled ordinary differential equations, order 
C     defined by increasing spatial positions:
C
c*     FUNCTION v_t
c      v_t = ...
C
C------------------------------------------------------
C
C   - Initial values of system of coupled ordinary
C     differential equations for t=0 in the same order: 
C
c*     FUNCTION v_0
c      v_0 = ...
C
C------------------------------------------------------
C
C   - Boundary and transition functions first at left
C     border of an area, then at right border of an
C     area, etc.:
C
c*     FUNCTION h_left
c      h_left = ...
C
C------------------------------------------------------
C
C   - Boundary and transition gradients w.r.t. spatial 
C     variable first at left border of an area, then
C     at right border of an area, etc.:
C
c*     FUNCTION h_x_left
c      h_x_left = 0
C
c*     FUNCTION v_x_left
c      v_x_left = 0
C
c*     FUNCTION h_x_right
c      h_x_right = 0
C
c*     FUNCTION v_x_right
c      v_x_right = 0
C
C------------------------------------------------------
C
C   - Fitting criteria, order defined by increasing 
C     spatial positions:
C
*     FUNCTION fit(i), i in ind
      fit(i) = h
C
C------------------------------------------------------
C
C   - Constraints (if exist):
C
C*     FUNCTION g1
C      g1 = ...
C
C------------------------------------------------------
C
*     END
C
C------------------------------------------------------
C
